#
# Flask-Keen
#
# Copyright (C) 2017 Boris Raicheff
# All rights reserved
#


from setuptools import setup


setup(
    name='Flask-Keen',
    version='0.1.0',
    description='Flask-Keen',
    author='Boris Raicheff',
    author_email='b@raicheff.com',
    url='https://github.com/raicheff/flask-keen',
    install_requires=['flask', 'keen'],
    py_modules=['flask_keen'],
)


# EOF
